-- This plugin is an enhanced version of the original AutoJett plugin (http://www.voupr.com/plugin.php?name=autojett).
-- I (Lanigiro Elbbarcs) copied it and changed it a little.
--
-- AutoJett commands are:
--   on all         - Jettison all ores
--   on <list>      - Keep ores in list. (e.g. he pe)
--   off            - Turns AutoJett off
--   list           - Lists ores which are kept
-- E.g.
--   Jettison all:                 /autojett on all
--   Keep vanazek and carbon:      /autojett on va ca
--   Keep lanthanic and heliocene: /autojett on la he

declare('AutoJett', AutoJett or {})

AutoJett.active = false
AutoJett.DropAll = false
-- if state is true, ore will be jettisoned
AutoJett.ore = {
   ['Premium Aquean Ore'] = {state=true, short="aq"},
   ['Premium Silicate Ore'] = {state=true, short="si"},
   ['Premium Carbonic Ore'] = {state=true, short="ca"},
   ['Premium Ferric Ore'] = {state=true, short="fe"},
   ['Premium Ishik Ore'] = {state=true, short="is"},
   ['Premium VanAzek Ore'] = {state=true, short="va"},
   ['Premium Xithricite Ore'] = {state=true, short="xi"},
   ['Lanthanic Ore'] = {state=true, short="la"},
   ['Denic Ore'] = {state=true, short="de"},
   ['Pyronic Ore'] = {state=true, short="py"},
   ['Apicene Ore'] = {state=true, short="ap"},
   ['Pentric Ore'] = {state=true, short="pe"},
   ['Heliocene Ore'] = {state=true, short="he"}
}

function AutoJett.print_usage()
	print('\127ffffffAutoJett commands are:')
	print('\127ffff00  on all\127o \t - Jettison all ores')
	print('\127ffff00  on <list>\127o \t - Keep ores in list. (e.g. he pe)')
	print('\127ffff00  off\127o \t\t - Turns AutoJett off')
	print('\127ffff00  list\127o \t\t - Lists ores which are kept')
	print("\127ffffff  E.g. Jettison all: \127ffff00/autojett on all \12700ff00\tor\t \127ffffffKeep vanazek and carbon: \127ffff00/autojett on va ca \12700ff00\tor\t \127ffffffKeep lanthanic and heliocene: \127ffff00/autojett on la he")
end

function AutoJett.exists_in_ship_cargo(itemid)
   for _,cargo_itemid in ipairs(GetShipInventory(GetActiveShipID()).cargo) do
      if cargo_itemid == itemid then
				 return true
      end
   end
   return false
end

AutoJett.jettison_lock = false
AutoJett.jettison_timer = Timer()
function AutoJett.jettison()
	 if AutoJett.jettison_lock ==true then 
			AutoJett.jettison_timer:SetTimeout(1000, function() AutoJett.jettison() end)
	 end
	 AutoJett.jettison_lock = true

	 local jettison_list = {}
   for _,itemid in ipairs(GetShipInventory(GetActiveShipID()).cargo) do
			local itemname = GetInventoryItemName(itemid)
			local quantity = GetInventoryItemQuantity(itemid)
			if AutoJett.ore[itemname] ~= nil then
				 if AutoJett.DropAll == true or AutoJett.ore[itemname].state == true then
						table.insert(jettison_list, {id=itemid,quantity=quantity})
				 end
			end
   end
	 JettisonMultiple(jettison_list)
	 AutoJett.jettison_lock = false
end


function AutoJett:OnEvent(event, itemid)
   if AutoJett.active == true and
   PlayerInStation() == false then
			AutoJett.jettison_timer:SetTimeout(1000, function() AutoJett.jettison() end)
   end
end

function AutoJett.list()
   if AutoJett.active == false then
      print('\127ffffffAutoJett is now OFF')
      return
   end
   if AutoJett.DropAll == true then
      print('\127ffffffAutoJett jettisons ALL ores')
      return
   end

   local listtbl = {}
   for k,v in pairs(AutoJett.ore) do
      if v.state == false then
				 table.insert(listtbl, k)
      end
   end
   print('\127ffffffAutoJett keeping ores: \127999999'..table.concat(listtbl, ', ')..'.')
end

function AutoJett.cmd(_,data)
   if not data then
      AutoJett.print_usage()
			
   elseif string.lower(data[1]) == 'on' then
      if data[2] ~= nil and string.lower(data[2]) == 'all' then
				 AutoJett.active = true
				 AutoJett.DropAll = true
				 print('\127ffffffAutoJett will now jettison ALL ores')

      elseif data[2] ~= nil and string.lower(data[2]) ~= nil then
				 -- reset all to true
				 for _,v in pairs(AutoJett.ore) do
						v.state = true
				 end
				 -- mark ores
				 local i = 2
				 local marked = 0
				 while data[i] ~= nil do
						for k,v in pairs(AutoJett.ore) do
							 if v.short == data[i] then
									v.state = false
									marked = marked + 1
							 end
						end
						i = i + 1
				 end
				 if marked > 0 then
						AutoJett.active = true
						AutoJett.DropAll = false
						AutoJett.list()
				 else
						AutoJett.print_usage()

						AutoJett.active = false
						print('\127ffffffAuto-Jettison is now OFF')
				 end

      else
				 AutoJett.print_usage()
      end

   elseif string.lower(data[1]) == 'off' then
      AutoJett.active = false
      print('\127ffffffAuto-Jettison is now OFF')
			
   elseif string.lower(data[1]) == 'list' then
      AutoJett.list()
   else
      AutoJett.print_usage()
   end
end

RegisterEvent(AutoJett, "INVENTORY_ADD")
RegisterEvent(AutoJett, "INVENTORY_UPDATE")

RegisterUserCommand('autojett', AutoJett.cmd)